@@ -28,6 +28,7 @@ class Remover:
             raise AssertionError('jit and enable pyramid blending cannot be used together')
         
         self.model = InSPyReNet_SwinB(depth=64, pretrained=False, base_size=base_size, threshold=threshold)
+        self.model.eval()
 
         checkpoint_dir = os.path.join(os.environ['HOME'], '.transparent-background')
         if os.path.isdir(checkpoint_dir) is False:
@@ -35,7 +36,7 @@ class Remover:
             
         download_and_unzip('latest.pth', URL, checkpoint_dir, False, md5=MD5)
 
-        self.model.load_state_dict(torch.load(os.path.join(checkpoint_dir, 'latest.pth'), map_location=torch.device('cpu')), strict=True)
+        self.model.load_state_dict(torch.load(os.path.join(checkpoint_dir, 'latest.pth'), map_location='cpu'), strict=True)
         
         self.use_gpu = False
         if torch.cuda.is_available():
@@ -64,7 +65,7 @@ class Remover:
             
         with torch.no_grad():
             pred = self.model(x)
-            
+
         pred = F.interpolate(pred, shape, mode='bilinear', align_corners=True)
         pred = pred.data.cpu()
         pred = pred.numpy().squeeze()   
@@ -108,7 +109,10 @@ def console():
         _format = get_format([args.source])
         
     else:
-        raise FileNotFoundError
+        raise FileNotFoundError('File or directory {} is invalid'.format(args.source))
+
+    if args.type == 'rgba' and _format == 'Video':
+        raise AttributeError('type rgba cannot be applied to video input')
         
     if args.dest is not None:
         save_dir = args.dest
@@ -123,7 +127,7 @@ def console():
 
     for img, name in samples:
         if _format == 'Video' and writer is None:
-            writer = cv2.VideoWriter(os.path.join(save_dir, name + '.mp4'), cv2.VideoWriter_fourcc(*'mp4v'), sample_list.fps, shape[::-1])
+            writer = cv2.VideoWriter(os.path.join(save_dir, name + '.mp4'), cv2.VideoWriter_fourcc(*'mp4v'), sample_list.fps, img.size)
             samples.total += int(sample_list.cap.get(cv2.CAP_PROP_FRAME_COUNT))
         if _format == 'Video' and img is None:
             if writer is not None:
@@ -136,4 +140,4 @@ def console():
         if _format == 'Image':
             Image.fromarray(out).save(os.path.join(save_dir, name + '.png'))
         elif _format == 'Video' and writer is not None:
-            writer.write(out)
\ No newline at end of file
+            writer.write(cv2.cvtColor(out, cv2.COLOR_BGR2RGB))
\ No newline at end of file
